@@ -23,7 +23,7 @@
 /* #undef WITH_GPROF */
 #define WITH_SIMD
 #define WITH_AVX2
-/* #undef WITH_CUPS */
+#define WITH_CUPS
 #define WITH_JPEG
 /* #undef WITH_WIN8 */
 /* #undef WITH_AAD */
@@ -120,7 +120,7 @@
 #define CHANNEL_PARALLEL_CLIENT
 /* #undef CHANNEL_PARALLEL_SERVER */
 #define CHANNEL_PRINTER
-/* #undef CHANNEL_PRINTER_CLIENT */
+#define CHANNEL_PRINTER_CLIENT
 /* #undef CHANNEL_PRINTER_SERVER */
 #define CHANNEL_RAIL
 #define CHANNEL_RAIL_CLIENT
@@ -178,8 +178,8 @@
 /* #undef CHANNEL_TSMF */
 /* #undef CHANNEL_TSMF_CLIENT */
 /* #undef CHANNEL_TSMF_SERVER */
-/* #undef CHANNEL_URBDRC */
-/* #undef CHANNEL_URBDRC_CLIENT */
+#define CHANNEL_URBDRC
+#define CHANNEL_URBDRC_CLIENT
 /* #undef CHANNEL_URBDRC_SERVER */
 #define CHANNEL_VIDEO
 #define CHANNEL_VIDEO_CLIENT
